# Kedata Text Analysis Package


<p align="center">
<a href="https://pypi.python.org/pypi/kedatatext">
    <img src="https://img.shields.io/pypi/v/kedatatext.svg"
        alt = "Release Status">
</a>

<a href="https://github.com/canggihpw/kedatatext/actions">
    <img src="https://github.com/canggihpw/kedatatext/actions/workflows/dev.yml/badge.svg" alt="dev CI Status">
</a>

<a href="https://github.com/canggihpw/kedatatext/actions">
    <img src="https://github.com/canggihpw/kedatatext/actions/workflows/release.yml/badge.svg" alt="release CI Status">
</a>

<a href="https://canggihpw.github.io/kedatatext/">
    <img src="https://img.shields.io/website/https/canggihpw.github.io/kedatatext/index.html.svg?label=docs&down_message=unavailable&up_message=available" alt="Documentation Status">
</a>

<a href="https://codecov.io/gh/canggihpw/kedatatext" >
    <img src="https://codecov.io/gh/canggihpw/kedatatext/graph/badge.svg?token=gQSMhgXOm0"/>
</a>

<a href="https://app.codacy.com/gh/canggihpw/kedatatext/dashboard" >
    <img src="https://app.codacy.com/project/badge/Grade/2f7adf5b938c425fb85247b1efea0ac2"/>
</a>

<a href="https://pypi.python.org/pypi/kedatatext">
    <img alt="PyPI - Python Version" src="https://img.shields.io/pypi/pyversions/kedatatext">
</a>

<a href="https://github.com/canggihpw/kedatatext/tree/main/kedatatext">
    <img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/canggihpw/kedatatext">
</a>



</p>


Skeleton project created by Python Project Wizard (ppw)


* Free software: MIT
* Documentation: <https://canggihpw.github.io/kedatatext/>


## Features

* TODO

## Credits

This package was created with the [ppw](https://zillionare.github.io/python-project-wizard) tool. For more information, please visit the [project page](https://zillionare.github.io/python-project-wizard/).
